@@ -1618,36 +1618,42 @@ get_host_ip (GSSDPNetworkDevice *device)
                       GAA_FLAG_SKIP_MULTICAST;
         DWORD size = 15360; /* Use 15k buffer initially as documented in MSDN */
         DWORD ret;
-        PIP_ADAPTER_ADDRESSES adapters_addresses;
+        PIP_ADAPTER_ADDRESSES adapters_addresses = NULL;
         PIP_ADAPTER_ADDRESSES adapter;
+        gboolean retval = FALSE;
 
         do {
-                adapters_addresses = (PIP_ADAPTER_ADDRESSES) g_malloc0 (size);
+                adapters_addresses = (PIP_ADAPTER_ADDRESSES) g_realloc (adapters_addresses, size);
                 ret = GetAdaptersAddresses (AF_UNSPEC,
                                             flags,
                                             NULL,
                                             adapters_addresses,
                                             &size);
-                if (ret == ERROR_BUFFER_OVERFLOW)
-                        g_free (adapters_addresses);
         } while (ret == ERROR_BUFFER_OVERFLOW);
 
         if (ret == ERROR_SUCCESS)
                 for (adapter = adapters_addresses;
                      adapter != NULL;
                      adapter = adapter->Next) {
-                        if (adapter->FirstUnicastAddress == NULL)
+                        g_debug ("Found adapter %s (%S)", adapter->AdapterName, adapter->FriendlyName);
+                        if (adapter->FirstUnicastAddress == NULL) {
+                                g_debug("  Skipping: No Unicast addresses");
                                 continue;
-                        if (adapter->OperStatus != IfOperStatusUp)
+                        }
+                        if (adapter->OperStatus != IfOperStatusUp) {
+                                g_debug("  Skipping: Not up!");
                                 continue;
+                        }
                         /* skip Point-to-Point devices */
-                        if (adapter->IfType == IF_TYPE_PPP)
+                        if (adapter->IfType == IF_TYPE_PPP) {
+                                g_debug("  Skipping: Interface is PPP");
                                 continue;
-
+                        }
                         if (device->iface_name != NULL &&
-                            strcmp (device->iface_name, adapter->AdapterName) != 0)
+                            !g_str_equal (device->iface_name, adapter->AdapterName)) {
+                                g_debug("  Skipping: Not matching %s", device->iface_name);
                                 continue;
-
+                        }
                         /* I think that IPv6 is done via pseudo-adapters, so
                          * that there are either IPv4 or IPv6 addresses defined
                          * on the adapter.
@@ -1672,6 +1678,7 @@ get_host_ip (GSSDPNetworkDevice *device)
                 p = NULL;
 
                 adapter = (PIP_ADAPTER_ADDRESSES) ifaceptr->data;
+                g_debug("Checking Adapter %S (%s)\n", adapter->FriendlyName, adapter->AdapterName);
 
                 for (address_prefix = adapter->FirstPrefix; address_prefix != NULL; address_prefix = address_prefix->Next)
                         if (address_prefix->Address.lpSockaddr->sa_family == AF_INET)
@@ -1692,6 +1699,15 @@ get_host_ip (GSSDPNetworkDevice *device)
                                                         q = prefix;
                         }
 
+                        if (p != NULL && device->host_ip != NULL && ! g_str_equal (p, device->host_ip)) {
+                                g_debug ("Skipping %s on %s because it does not match the requested IP %s",
+                                         p,
+                                         adapter->AdapterName,
+                                         ip);
+                                p = NULL;
+                                continue;
+                        }       
+
                         if (p != NULL) {
                                 gint32 mask = 0;
 
@@ -1713,12 +1729,13 @@ get_host_ip (GSSDPNetworkDevice *device)
                                                             (guint) address_prefix->PrefixLength);
                                 device->address_mask = g_inet_address_mask_new_from_string (mask_str, NULL);
                                 g_free (mask_str);
+								
 
                                 if (device->iface_name == NULL)
                                         device->iface_name = g_strdup (adapter->AdapterName);
                                 if (device->network == NULL)
                                         device->network = g_strdup (q);
-                                break;
+                                retval = TRUE;
                         }
                 }
 
@@ -1726,10 +1743,13 @@ get_host_ip (GSSDPNetworkDevice *device)
                         break;
 
         }
+
+        // Not freeing up the members of the list as they are just
+        // pointing into adapters_addresses which is freed below
         g_list_free (up_ifaces);
         g_free (adapters_addresses);
 
-        return TRUE;
+        return retval;
 #elif defined(__BIONIC__)
         struct      ifreq *ifaces = NULL;
         struct      ifreq *iface = NULL;
@@ -1940,6 +1960,7 @@ success:
 #else
         struct ifaddrs *ifa_list, *ifa;
         GList *up_ifaces, *ifaceptr;
+        gboolean retval = FALSE;
 
         up_ifaces = NULL;
 
@@ -1991,6 +2012,13 @@ success:
                                &s4->sin_addr,
                                ip,
                                sizeof (ip));
+                if (device->host_ip != NULL &&
+                    !g_str_equal (device->host_ip, p)) {
+                        p = NULL;
+
+                        continue;
+                }
+
                 device->host_ip = g_strdup (p);
 
                 bytes = (const guint8 *) &s4->sin_addr;
@@ -2019,13 +2047,14 @@ success:
                         device->iface_name = g_strdup (ifa->ifa_name);
                 if (device->network == NULL)
                         device->network = g_strdup (q);
-                break;
+
+                retval = TRUE;
         }
 
         g_list_free (up_ifaces);
         freeifaddrs (ifa_list);
 
-        return TRUE;
+        return retval;
 #endif
 }
 
@@ -2034,30 +2063,12 @@ init_network_info (GSSDPClient *client, GError **error)
 {
         gboolean ret = TRUE;
 
-        /* Either interface name or host_ip wasn't given during construction.
-         * If one is given, try to find the other, otherwise just pick an
-         * interface.
-         */
-        if (client->priv->device.iface_name == NULL ||
-            client->priv->device.host_ip == NULL)
-                get_host_ip (&(client->priv->device));
-        else {
-                /* Ugly. Ideally, get_host_ip needs to be run everytime, but
-                 * it is currently to stupid so just query index here if we
-                 * have a name and an interface already.
-                 *
-                 * query_ifindex will return -1 on platforms that don't
-                 * support this.
-                 */
-                client->priv->device.index =
-                                query_ifindex (client->priv->device.iface_name);
-        }
-
-        if (client->priv->device.host_addr == NULL &&
-            client->priv->device.host_ip != NULL) {
-                client->priv->device.host_addr =
-                                g_inet_address_new_from_string
-                                    (client->priv->device.host_ip);
+        if (!get_host_ip (&(client->priv->device))) {
+                g_set_error_literal (error,
+                                     GSSDP_ERROR,
+                                     GSSDP_ERROR_FAILED,
+                                     "Could not determine network device");
+                ret = FALSE;
         }
 
         if (client->priv->device.iface_name == NULL) {
