@@ -23,6 +23,7 @@
 #define __GSSDP_CLIENT_H__
 
 #include <glib-object.h>
+#include <gio/gio.h>
 
 G_BEGIN_DECLS
 
@@ -108,6 +109,9 @@ gssdp_client_get_network      (GSSDPClient  *client);
 gboolean
 gssdp_client_get_active       (GSSDPClient  *client);
 
+GInetAddressMask *
+gssdp_client_get_address_mask (GSSDPClient *client);
+
 void
 gssdp_client_append_header    (GSSDPClient *client,
                                const char  *name,
@@ -120,6 +124,15 @@ gssdp_client_remove_header    (GSSDPClient *client,
 void
 gssdp_client_clear_headers    (GSSDPClient *client);
 
+void
+gssdp_client_add_cache_entry  (GSSDPClient  *client,
+                               const char   *ip_address,
+                               const char   *user_agent);
+
+const char *
+gssdp_client_guess_user_agent (GSSDPClient *client,
+                               const char  *ip_address);
+
 G_END_DECLS
 
 #endif /* __GSSDP_CLIENT_H__ */
